@@ -23,8 +23,7 @@ class TestBuildInfoRetrieval(object):
             raise SkipTest()
 
     def test_repo_owner(self):
-        builds = self.client.get_builds('apiaryio', 'apiary')
-        print builds[0]
+        builds = self.client.get_builds('apiaryio', 'ivy')
+        # print builds[0]
         assert len(builds) > 0
-        raise NotImplementedError()
 
